@@ -3,8 +3,10 @@ function _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizerProps(p) {
         return;
     visitedObjects.add(p);
     try {
-        if (!visitedObjects.has(p.userPoolClients))
-            require("@aws-cdk/aws-cognito/.warnings.jsii.js")._aws_cdk_aws_cognito_IUserPoolClient(p.userPoolClients);
+        if (p.userPoolClients != null)
+            for (const o of p.userPoolClients)
+                if (!visitedObjects.has(o))
+                    require("@aws-cdk/aws-cognito/.warnings.jsii.js")._aws_cdk_aws_cognito_IUserPoolClient(o);
     }
     finally {
         visitedObjects.delete(p);
@@ -23,8 +25,10 @@ function _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaAuthorizerProps(p) {
         return;
     visitedObjects.add(p);
     try {
-        if (!visitedObjects.has(p.responseTypes))
-            _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaResponseType(p.responseTypes);
+        if (p.responseTypes != null)
+            for (const o of p.responseTypes)
+                if (!visitedObjects.has(o))
+                    _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaResponseType(o);
     }
     finally {
         visitedObjects.delete(p);
